==> haskell-reinterpret-cast-0.1.0-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-reinterpret-cast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reinterpret-cast
version: 0.1.0
id: reinterpret-cast-0.1.0-DAz8OKA2zDaENtEB263RfL
key: reinterpret-cast-0.1.0-DAz8OKA2zDaENtEB263RfL
license: MIT
copyright: 2014 Niklas Hambüchen <mail@nh2.me>
maintainer: Niklas Hambüchen <mail@nh2.me>
author: Niklas Hambüchen <mail@nh2.me>
stability: experimental
homepage: https://github.com/nh2/reinterpret-cast
synopsis: Memory reinterpretation casts for Float/Double and Word32/Word64
description:
    Memory reinterpretation casts for Float\/Double and Word32\/Word64.
    .
    The implementations in the @.Internal@ package are different ways to tackle
    the problem; the @array@ method (current default) is about 5 times faster
    than the @FFI@ method.
category: Data
abi: 1f855cf2b3ad1ba5b69d6eed165d99ba
exposed: True
exposed-modules:
    Data.ReinterpretCast Data.ReinterpretCast.Internal.ImplArray
    Data.ReinterpretCast.Internal.ImplFFI
import-dirs: /usr/lib/ghc-8.6.5/site-local/reinterpret-cast-0.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/reinterpret-cast-0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/reinterpret-cast-0.1.0
hs-libraries: HSreinterpret-cast-0.1.0-DAz8OKA2zDaENtEB263RfL
depends:
    array-0.5.3.0 base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-reinterpret-cast/html/reinterpret-cast.haddock
haddock-html: /usr/share/doc/haskell-reinterpret-cast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reinterpret-cast-0.1.0-30-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-reinterpret-cast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reinterpret-cast
version: 0.1.0
id: reinterpret-cast-0.1.0-Ji6wJiGyu3gE8VKkueyhik
key: reinterpret-cast-0.1.0-Ji6wJiGyu3gE8VKkueyhik
license: MIT
copyright: 2014 Niklas Hambüchen <mail@nh2.me>
maintainer: Niklas Hambüchen <mail@nh2.me>
author: Niklas Hambüchen <mail@nh2.me>
stability: experimental
homepage: https://github.com/nh2/reinterpret-cast
synopsis: Memory reinterpretation casts for Float/Double and Word32/Word64
description:
    Memory reinterpretation casts for Float\/Double and Word32\/Word64.
    .
    The implementations in the @.Internal@ package are different ways to tackle
    the problem; the @array@ method (current default) is about 5 times faster
    than the @FFI@ method.
category: Data
abi: 2525a86ca5332d813a74208c675a1b5a
exposed: True
exposed-modules:
    Data.ReinterpretCast Data.ReinterpretCast.Internal.ImplArray
    Data.ReinterpretCast.Internal.ImplFFI
import-dirs: /usr/lib/ghc-8.6.5/site-local/reinterpret-cast-0.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/reinterpret-cast-0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/reinterpret-cast-0.1.0
hs-libraries: HSreinterpret-cast-0.1.0-Ji6wJiGyu3gE8VKkueyhik
depends:
    array-0.5.3.0 base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-reinterpret-cast/html/reinterpret-cast.haddock
haddock-html: /usr/share/doc/haskell-reinterpret-cast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
